#!/bin/sh -x

# bootstrap.sh script for the source distribution of POV-Ray 3.8 (povr branch)
# for Linux, MacOS and UNIX.
#
# Please report bugs to the issue tracker at:
#   https://github.com/POV-Ray/povray/issues
# and post questions to the news group at:
#   http://news.povray.org/povray.unix
#.
# This specific booststrap script created in the directory
# <source package install>/unix by the prebuild.sh script.

# NOTE! Run this script if configure.ac or any Makefile.am has changed

rm -f config.log config.status

# Create aclocal.m4 for extra automake and autoconf macros
aclocal -I .

# Create config.h.in
autoheader --warnings=all

# Create all Makefile.in's from Makefile.am's
automake --foreign --add-missing --warnings=all

# Create configure from configure.ac
autoconf --warnings=all

# User doesn't need to see patching work...
set +x

# Patch for ugly ar -cru warnings:
# warning : ar: u modifier ignored since D is the default (see U)
# This an autotools "issue" long not fixed in shipped update.
cd platform
sed "s,ARFLAGS = cru,ARFLAGS = cr,g" ./Makefile.in > ./Makefile.in.tmp
mv -f ./Makefile.in.tmp ./Makefile.in
cd ..

cd source
sed "s,ARFLAGS = cru,ARFLAGS = cr,g" ./Makefile.in > ./Makefile.in.tmp
mv -f ./Makefile.in.tmp ./Makefile.in
cd ..

cd vfe
sed "s,ARFLAGS = cru,ARFLAGS = cr,g" ./Makefile.in > ./Makefile.in.tmp
mv -f ./Makefile.in.tmp ./Makefile.in
cd ..


# Post-process DIST_COMMON in unix/Makefile.in
# Done to avoid getting the files in 'make dist' tar balls.
cd unix
for file in AUTHORS COPYING NEWS README configure.ac ChangeLog; do
  sed "s,$file,,g" ./Makefile.in > ./Makefile.in.tmp
  mv -f ./Makefile.in.tmp ./Makefile.in
done
cd ..

# Small post-fixes to 'configure'
#   add --srcdir when using --help=recursive
#   protect $ac_(pop)dir with double quotes in cd commands
#   protect $am_aux_dir with double quotes when looking for 'missing'
cat ./configure | sed \
  -e 's,configure.gnu  --help=recursive,& --srcdir=$ac_srcdir,g' \
  -e 's,\(cd \)\($ac_\)\(pop\)*\(dir\),\1"\2\3\4",g' \
  -e 's,$am_aux_dir/missing,\\"$am_aux_dir\\"/missing,g' \
  > ./configure.tmp
mv -f ./configure.tmp ./configure
chmod +x ./configure

# Remove cache directory
rm -f -r ./autom4te.cache
